@@ -47,19 +47,6 @@ Q_REQUIRED_RESULT static inline QColor aiColorToQColor(const aiColor4D &color)
     return QColor::fromRgbF(color.r, color.g, color.b, color.a);
 }
 
-static QByteArrayView fromAiString(QSSGSceneDesc::Scene::Allocator &allocator, const aiString &string)
-{
-    const qsizetype length = string.length;
-    if (length > 0) {
-        const qsizetype asize = length + 1;
-        char *data = reinterpret_cast<char *>(allocator.allocate(asize));
-        qstrncpy(data, string.data, length + 1);
-        return QByteArrayView{data, length};
-    }
-
-    return QByteArrayView();
-}
-
 static QByteArray fromAiString(const aiString &string)
 {
     const qsizetype length = string.length;
@@ -133,11 +120,13 @@ struct SceneInfo
     struct Options
     {
         bool gltfMode = false;
+        bool fbxMode = false;
         bool binaryKeyframes = false;
         bool forceMipMapGeneration = false;
         bool useFloatJointIndices = false;
         bool generateLightmapUV = false;
         bool designStudioWorkarounds = false;
+
         int lightmapBaseResolution = 1024;
         float globalScaleValue = 1.0;
 
@@ -344,8 +333,6 @@ static void setMaterialProperties(QSSGSceneDesc::Material &target, const aiMater
         aiString texturePath;
         TextureInfo texInfo;
 
-        auto &scene = target.scene;
-
         if (material.GetTexture(textureType, index, &texturePath, &texInfo.mapping, &texInfo.uvIndex, nullptr, nullptr, texInfo.modes) == aiReturn_SUCCESS) {
             if (texturePath.length > 0) {
                 aiUVTransform transform;
@@ -510,8 +497,12 @@ static void setMaterialProperties(QSSGSceneDesc::Material &target, const aiMater
                 else if (QByteArrayView(alphaMode.C_Str()) == "BLEND")
                     mode = QQuick3DPrincipledMaterial::AlphaMode::Blend;
 
-                if (mode != QQuick3DPrincipledMaterial::AlphaMode::Default)
+                if (mode != QQuick3DPrincipledMaterial::AlphaMode::Default) {
                     QSSGSceneDesc::setProperty(target, "alphaMode", &QQuick3DPrincipledMaterial::setAlphaMode, mode);
+                    // If the mode is mask, we also need to force OpaquePrePassDepthDraw mode
+                    if (mode == QQuick3DPrincipledMaterial::AlphaMode::Mask)
+                        QSSGSceneDesc::setProperty(target, "depthDrawMode", &QQuick3DPrincipledMaterial::setDepthDrawMode, QQuick3DMaterial::OpaquePrePassDepthDraw);
+                }
             }
         }
 
@@ -778,8 +769,12 @@ static void setMaterialProperties(QSSGSceneDesc::Material &target, const aiMater
                 else if (QByteArrayView(alphaMode.C_Str()) == "BLEND")
                     mode = QQuick3DSpecularGlossyMaterial::AlphaMode::Blend;
 
-                if (mode != QQuick3DSpecularGlossyMaterial::AlphaMode::Default)
+                if (mode != QQuick3DSpecularGlossyMaterial::AlphaMode::Default) {
                     QSSGSceneDesc::setProperty(target, "alphaMode", &QQuick3DSpecularGlossyMaterial::setAlphaMode, mode);
+                    // If the mode is mask, we also need to force OpaquePrePassDepthDraw mode
+                    if (mode == QQuick3DSpecularGlossyMaterial::AlphaMode::Mask)
+                    QSSGSceneDesc::setProperty(target, "depthDrawMode", &QQuick3DSpecularGlossyMaterial::setDepthDrawMode, QQuick3DMaterial::OpaquePrePassDepthDraw);
+                }
             }
         }
 
@@ -915,19 +910,30 @@ static void setCameraProperties(QSSGSceneDesc::Camera &target, const aiCamera &s
     // the case we have to do additional transform
     aiMatrix4x4 correctionMatrix;
     bool needsCorrection = false;
-    aiVector3D upQuick3D = aiVector3D(0, 1, 0);
-    if (source.mLookAt != aiVector3D(0, 0, -1)) {
-        aiMatrix4x4 lookAtCorrection;
-        aiMatrix4x4::FromToMatrix(aiVector3D(0, 0, -1), source.mLookAt, lookAtCorrection);
-        correctionMatrix *= lookAtCorrection;
-        needsCorrection = true;
-        upQuick3D *= lookAtCorrection;
-    }
-    if (source.mUp != upQuick3D) {
-        aiMatrix4x4 upCorrection;
-        aiMatrix4x4::FromToMatrix(upQuick3D, source.mUp, upCorrection);
-        correctionMatrix = upCorrection * correctionMatrix;
+
+    // Workaround For FBX,
+    // assimp has a problem to set properties, mLookAt ans mUp
+    // and it takes too much time for correction.
+    // Quick3D will ignore these value and just use
+    // the initial differences between FBX and Quick3D.
+    if (sceneInfo.opt.fbxMode) {
+        aiMatrix4x4::RotationY(ai_real(M_PI / 2), correctionMatrix);
         needsCorrection = true;
+    } else {
+        aiVector3D upQuick3D = aiVector3D(0, 1, 0);
+        if (source.mLookAt != aiVector3D(0, 0, -1)) {
+            aiMatrix4x4 lookAtCorrection;
+            aiMatrix4x4::FromToMatrix(aiVector3D(0, 0, -1), source.mLookAt, lookAtCorrection);
+            correctionMatrix *= lookAtCorrection;
+            needsCorrection = true;
+            upQuick3D *= lookAtCorrection;
+        }
+        if (source.mUp != upQuick3D) {
+            aiMatrix4x4 upCorrection;
+            aiMatrix4x4::FromToMatrix(upQuick3D, source.mUp, upCorrection);
+            correctionMatrix = upCorrection * correctionMatrix;
+            needsCorrection = true;
+        }
     }
 
     setNodeProperties(target, sourceNode, sceneInfo, needsCorrection ? &correctionMatrix : nullptr);
@@ -1223,7 +1229,6 @@ static QSSGSceneDesc::Node *createSceneNode(const NodeInfo &nodeInfo,
                                             QSSGSceneDesc::Node &parent,
                                             const SceneInfo &sceneInfo)
 {
-    auto &targetScene = parent.scene;
     QSSGSceneDesc::Node *node = nullptr;
     const auto &srcScene = sceneInfo.scene;
     switch (nodeInfo.type) {
@@ -1296,7 +1301,6 @@ static void processNode(const SceneInfo &sceneInfo, const aiNode &source, QSSGSc
         }
         node = createSceneNode(NodeInfo { 0, QSSGSceneDesc::Node::Type::Model }, source, parent, sceneInfo);
         if (!morphProps.isEmpty()) {
-            auto &targetScene = parent.scene;
             const QString nodeName(source.mName.C_Str());
             QVarLengthArray<QSSGSceneDesc::MorphTarget *> morphTargets;
             morphTargets.reserve(morphProps.size());
@@ -1700,7 +1704,14 @@ static QString importImp(const QUrl &url, const QJsonObject &options, QSSGSceneD
     }
 
     // Get Options
-    const auto opt = processSceneOptions(options);
+    auto opt = processSceneOptions(options);
+    // check if the asset is GLTF format
+    const auto extension = sourceFile.suffix().toLower();
+    if (extension == QStringLiteral("gltf") || extension == QStringLiteral("glb"))
+        opt.gltfMode = true;
+    else if (extension == QStringLiteral("fbx"))
+        opt.fbxMode = true;
+
     SceneInfo sceneInfo { *sourceScene, materials, meshes, embeddedTextures,
                           textureMap, skins, mesh2skin, sourceFile.dir(), opt };
 
@@ -1764,6 +1775,8 @@ static QString importImp(const QUrl &url, const QJsonObject &options, QSSGSceneD
         auto &channels = targetAnimation.channels;
         qreal freq = qFuzzyIsNull(srcAnim.mTicksPerSecond) ? 1.0
                                         : 1000.0 / srcAnim.mTicksPerSecond;
+        targetAnimation.framesPerSecond = srcAnim.mTicksPerSecond;
+        targetAnimation.name = fromAiString(srcAnim.mName);
         // Process property channels
         for (It i = 0, end = srcAnim.mNumChannels; i != end; ++i) {
             const auto &srcChannel = *srcAnim.mChannels[i];
